<?php
/***************************************************************
*  Copyright notice
*
*  (c) 2006 Kraft Bernhard (kraftb@kraftb.at)
*  (c) 2006 Stefan Galinski (stefan.galinski@frm2.tum.de)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

/**
 * Wizard for input-field-calendar
 *
 * $Id$
 *
 * @author	Kraft Bernhard <kraftb@kraftb.at>
 * @author	Stefan Galinski <stefan.galinski@frm2.tum.de>
 */
class tx_date2cal_wizard
{
	/**
	 * renders date/datetime fields
	 *
	 * @param array TCA informations about date/datetime field
	 * @param object TCE forms object
	 * @return rendered item
	 */
	function renderWizard($params, &$pObj)
	{
		$this->pObj = $pObj;
		$evalStr = $GLOBALS['TCA'][$params['table']]['columns'][$params['field']]['config']['eval'];
		$evalList = t3lib_div::trimExplode(',', $evalStr, 1);

		// only date/datetime fields
		if(!in_array('date', $evalList) && !in_array('datetime', $evalList))
			return '';

		// add id attribute
		$params['item'] = str_replace('<input type="text"', '<input type="text" ' .
			'id="' . $params['itemName'] . '"', $params['item']);

		// format definition
		if(in_array('datetime', $evalList))	{
			$jsDate = '%H:%M %d-%m-%Y';
			if($GLOBALS['TYPO3_CONF_VARS']['SYS']['USdateFormat'])
				$jsDate = '%H:%M %m-%d-%Y';
		} else {
			$jsDate = '%d-%m-%Y';
			if($GLOBALS['TYPO3_CONF_VARS']['SYS']['USdateFormat'])
				$jsDate = '%m-%d-%Y';
		}

		// generate calendar call
		$title = $GLOBALS['LANG']->sL('LLL:EXT:date2cal/locallang.xml:calendar_wizard');
		$item = '<img class="calImg" src="' . $GLOBALS['BACK_PATH'] .
			t3lib_extMgm::extRelPath('date2cal') . 'jscalendar/img.gif" ' .
			'id="' . $params['itemName'] . '_trigger" style="cursor: pointer;" ' .
			'title="' . $title . '" alt="' . $title . '" />
			<script type="text/javascript">
			Calendar.setup({
				inputField  : "' . $params['itemName'] . '",
				ifFormat    : "' . $jsDate . '",
				button      : "' . $params['itemName'] . '_trigger"' .
				(in_array('datetime', $evalList) ? '
				,showsTime  : true,
				time24      : true
				' : '') . '
			});
			</script>';

		// add javascript initialisation code
		if(!$this->pObj->additionalCode_pre['date2cal'])
			$this->addJScode();

		return $item;
	}

	/**
	 * adds some javascript code to initialize JSCalendar
	 *
	 * @return void
	 */
	function addJScode()
	{
		// get extension configuration
		$extConfig = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf']['date2cal']);

		// current language or prefered language
		$groupOrUserProps = t3lib_BEfunc::getModTSconfig($this->pageinfo['uid'], 'tx_date2cal');
		if(!empty($groupOrUserProps['properties']['prefLang']))
			$curLang = $groupOrUserProps['properties']['prefLang'];
		else
			$curLang = $GLOBALS['LANG']->lang;

		// convert/check language
		if(array_key_exists($curLang, $GLOBALS['LANG']->csConvObj->isoArray))
			$curLang = $GLOBALS['LANG']->csConvObj->isoArray[$curLang];
		if(is_file(PATH_site . t3lib_extMgm::siteRelPath('date2cal') .
			'jscalendar/lang/calendar-' . $curLang . '-utf8.js') &&
			$GLOBALS['TYPO3_CONF_VARS']['BE']['forceCharset'] == 'utf-8')
			$curLang .= '-utf8';
		elseif(!is_file(PATH_site . t3lib_extMgm::siteRelPath('date2cal') .
			'jscalendar/lang/calendar-' . $curLang . '.js'))
			$curLang = 'en';

		// initialisation javascript + css
		$this->pObj->additionalCode_pre['date2cal'] = '
			<!-- inclusion of JSCalendar -->
			<script type="text/javascript" src="' . t3lib_extMgm::extRelPath('date2cal') .
				'jscalendar/calendar.js"></script>
			<script type="text/javascript" src="' . t3lib_extMgm::extRelPath('date2cal') .
				'jscalendar/lang/calendar-en.js"></script>
			<script type="text/javascript" src="' . t3lib_extMgm::extRelPath('date2cal') .
				'jscalendar/lang/calendar-' .
				((($GLOBALS['LANG']->lang == 'default') || (!$curLang)) ?
				'en' : $curLang) . '.js"></script>
			<script type="text/javascript" src="' . t3lib_extMgm::extRelPath('date2cal') .
				'jscalendar/calendar-setup.js"></script>
			<link rel="stylesheet" type="text/css" href="' . t3lib_extMgm::extRelPath('date2cal') .
				'jscalendar/skins/' . $extConfig['calendarCSS'] .'" />';
	}
}
?>
